# Matching

## Bipartite Matching
*LightGraphsExtras.Matching* supports maximum weight maximal matching computation on bipartite graphs
through linear programming relaxation.  In fact, on bipartite graphs, the solution
of the linear problem is integer.

Installation of the `JuMP` package and at least one solver is required.

    maximum_weight_maximal_matching{T<:Number}(g, w::Dict{Edge,T})
    maximum_weight_maximal_matching{T<:Number}(g, w::Dict{Edge,T}, cutoff)

Given a bipartite graph `g` and an edgemap `w` containing weights associated to edges,
returns a matching with the maximum total weight among the ones containing the
greatest number of edges.

Edges in `g` not present in `w` will not be considered for the matching.

The algorithm relies on a linear relaxation on of the matching problem, which is
guaranteed to have integer solution on bipartite graps.

Eventually a `cutoff` argument can be given, to reduce computational times
excluding edges with weights lower than the cutoff.

The returned object is of type

    type MatchingResult
        weight::Float64
        inmatch::Dict{Edge,Bool}
        m::Vector{Int}
    end

where

weight: total weight of the matching

inmatch: `inmatch[e]=true` if edge `e` belongs to the matching.

m:       `m[i]=j` if vertex `i` is matched to vertex `j`.
         `m[i]=-1` for unmatched vertices.
